# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.1

([Full Changelog](https://github.com/tobinjones/pep723widget/compare/v0.3.0...775924e05e88b0c321c0aea473c3a00bdfec41ee))

### Enhancements made

- Add notebook initialization feature with PEP 723 metadata [#4](https://github.com/tobinjones/pep723widget/pull/4) ([@tobinjones](https://github.com/tobinjones))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/tobinjones/pep723widget/graphs/contributors?from=2025-07-16&to=2025-08-22&type=c))

[@tobinjones](https://github.com/search?q=repo%3Atobinjones%2Fpep723widget+involves%3Atobinjones+updated%3A2025-07-16..2025-08-22&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/tobinjones/pep723widget/compare/v0.2.0...0a49d807a6e11f916ee5dc37e2e4fb752c05f48d))

### Enhancements made

- Add comprehensive lockfile handling and UI improvements [#3](https://github.com/tobinjones/pep723widget/pull/3) ([@tobinjones](https://github.com/tobinjones))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/tobinjones/pep723widget/graphs/contributors?from=2025-07-15&to=2025-07-16&type=c))

[@tobinjones](https://github.com/search?q=repo%3Atobinjones%2Fpep723widget+involves%3Atobinjones+updated%3A2025-07-15..2025-07-16&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/tobinjones/pep723widget/compare/v0.1.1...dd854987272762275fcec317af71fc145506e960))

### Enhancements made

- Add PEP 723 dependency management feature [#2](https://github.com/tobinjones/pep723widget/pull/2) ([@tobinjones](https://github.com/tobinjones))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/tobinjones/pep723widget/graphs/contributors?from=2025-07-14&to=2025-07-15&type=c))

[@tobinjones](https://github.com/search?q=repo%3Atobinjones%2Fpep723widget+involves%3Atobinjones+updated%3A2025-07-14..2025-07-15&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/tobinjones/pep723widget/compare/35f1bc40396d194b3a5b77d54b47eba1ffef1b8e...a5fe55959fd089acfeba716cec577bbe9f50871b))

### Enhancements made

- Add PEP 723 notebook viewer extension [#1](https://github.com/tobinjones/pep723widget/pull/1) ([@tobinjones](https://github.com/tobinjones))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/tobinjones/pep723widget/graphs/contributors?from=2025-07-14&to=2025-07-14&type=c))

[@tobinjones](https://github.com/search?q=repo%3Atobinjones%2Fpep723widget+involves%3Atobinjones+updated%3A2025-07-14..2025-07-14&type=Issues)
